@@ -1,12 +1,9 @@
 /* Everything */
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 4
+#define QT_POINTER_SIZE 8
 
 // Compiler sub-arch support
-#define QT_COMPILER_SUPPORTS_SSE2 1
-#define QT_COMPILER_SUPPORTS_SSE3 1
-#define QT_COMPILER_SUPPORTS_SSSE3 1
 
 #ifndef QT_BOOTSTRAPPED
 
@@ -64,6 +61,12 @@
 # define QT_NO_TABLET
 #endif
 
+#if defined(QT_NO_TSLIB) && defined(QT_TSLIB)
+# undef QT_NO_TSLIB
+#elif !defined(QT_NO_TSLIB) && !defined(QT_TSLIB)
+# define QT_NO_TSLIB
+#endif
+
 #if defined(QT_NO_XINPUT) && defined(QT_XINPUT)
 # undef QT_NO_XINPUT
 #elif !defined(QT_NO_XINPUT) && !defined(QT_XINPUT)
@@ -100,12 +103,6 @@
 # define QT_RUNTIME_XRANDR
 #endif
 
-#if defined(QT_USE_MATH_H_FLOATS) && defined(QT_NO_USE_MATH_H_FLOATS)
-# undef QT_USE_MATH_H_FLOATS
-#elif !defined(QT_USE_MATH_H_FLOATS) && !defined(QT_NO_USE_MATH_H_FLOATS)
-# define QT_USE_MATH_H_FLOATS
-#endif
-
 #endif // QT_BOOTSTRAPPED
 
 #define QT_VISIBILITY_AVAILABLE
